function branchlist=nmfm_branch_list(type)
%% Return list of branches emerging from bifurcation
% (typically codim 1 branches emerging from codim 2 points)
%% Input
% * |type|: flag used for codim 2 point. Supported: hoho, genh, zeho. All
% others return no branches
%% Output
% * |branchlist|: array of structures with fields |name| (used to construct
% function call), |selection| (which branches to select, for example, in a
% Hopf-Hopf interaction, one wants only the first Hopf bifurcation, as the
% second one is the current branch), |reverse| (logical, a hint whether
% this bifurcation should be continued in both directions)
%
% (c) DDE-BIFTOOL v. 3.2a(309), 28/10/2018
%%
switch type
    case 'hoho'
        branchlist=struct('name',{'hopf','TorusBifurcation'},...
            'selection',{1,1:2},'reverse',{true,false});
    case 'genh'
        branchlist=struct('name','POfold','selection',1,'reverse',false);
    case 'zeho'
        branchlist=struct('name',{'hopf','fold','TorusBifurcation'},...
            'selection',{1,1,1},'reverse',{false,true,false});
    otherwise
        branchlist=struct('name',{},'selection',{},'reverse',{});
end
end

        
        